# mathcad2smath
Command tool to convert mathcad XMCD to XMCD with Smath Studio support

In progress...

TODO change to lxml?

TODO IF Statement wrong cases (most works)

TODO inline replaces to xml

TODO correct namespaces (refactor)

TODO and more...
